@@ -1,9 +1,4 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
-#
-# config.py
-#
-# Copyright 2011 - 2015 Patrick Ulbrich <zulu99@gmx.net>
+# Copyright 2011 - 2019 Patrick Ulbrich <zulu99@gmx.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +18,7 @@
 
 import os
 import xdg.BaseDirectory as bd
-from ConfigParser import RawConfigParser
+from configparser import RawConfigParser
 
 mailnag_defaults = {
 	'core':
@@ -32,7 +27,6 @@ mailnag_defaults = {
 		'imap_idle_timeout'	: '10',
 		'autostart'			: '1',
 		'connectivity_test'	: 'auto',
-		'credentialstore'	: 'auto',
 		'enabled_plugins'	: 'dbusplugin, soundplugin, libnotifyplugin'
 	}
 }
@@ -46,7 +40,7 @@ def cfg_exists():
 
 def read_cfg():
 	cfg = RawConfigParser()
-	cfg._sections = mailnag_defaults # HACK : use cfg.read_dict(mailnag_defaults) in python 3
+	cfg.read_dict(mailnag_defaults)
 
 	if os.path.exists(cfg_file):
 		cfg.read(cfg_file)
@@ -58,4 +52,4 @@ def write_cfg(cfg):
 	if not os.path.exists(cfg_folder):
 		os.makedirs(cfg_folder)
 	
-	with open(cfg_file, 'wb') as configfile: cfg.write(configfile)
+	with open(cfg_file, 'w') as configfile: cfg.write(configfile)
