@@ -1,9 +1,4 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
-#
-# libnotifyplugin.py
-#
-# Copyright 2013 - 2016 Patrick Ulbrich <zulu99@gmx.net>
+# Copyright 2013 - 2020 Patrick Ulbrich <zulu99@gmx.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +30,6 @@ from Mailnag.common.plugins import Plugin, HookTypes
 from Mailnag.common.i18n import _
 from Mailnag.common.subproc import start_subprocess
 from Mailnag.common.exceptions import InvalidOperationException
-from Mailnag.daemon.mails import sort_mails
 
 NOTIFICATION_MODE_COUNT			= '0'
 NOTIFICATION_MODE_SHORT_SUMMARY	= '3'
@@ -69,7 +63,7 @@ class LibNotifyPlugin(Plugin):
 		# initialize Notification
 		if not self._initialized:
 			Notify.init("Mailnag")
-			self._is_gnome = os.environ.has_key('GDMSESSION') and \
+			self._is_gnome = 'GDMSESSION' in os.environ and \
 				(os.environ['GDMSESSION'] == 'gnome')
 			self._initialized = True
 		
@@ -105,9 +99,8 @@ class LibNotifyPlugin(Plugin):
 	def get_manifest(self):
 		return (_("LibNotify Notifications"),
 				_("Shows a popup when new mails arrive."),
-				"1.1.1",
-				"Patrick Ulbrich <zulu99@gmx.net>",
-				False)
+				"2.0",
+				"Patrick Ulbrich <zulu99@gmx.net>")
 
 
 	def get_default_config(self):
@@ -265,7 +258,7 @@ class LibNotifyPlugin(Plugin):
 	def _notify_single(self, mails):
 		# In single notification mode new mails are
 		# added to the *bottom* of the notification list.
-		mails = sort_mails(mails, sort_desc = False)
+		mails.sort(key = lambda m: m.datetime, reverse = False)
 		
 		for mail in mails:
 			n = self._get_notification(self._get_sender(mail), mail.subject, "mail-unread")
@@ -292,7 +285,7 @@ class LibNotifyPlugin(Plugin):
 	
 	def _close_notifications(self):
 		with self._lock:
-			for n in self._notifications.itervalues():
+			for n in self._notifications.values():
 				n.close()
 			self._notifications = {}
 	
